Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ContentTypes ¶
type Endpoint ¶
type Endpoint struct {
Method string `yaml:"method,omitempty"`
Summary string `yaml:"summary,omitempty"`
Description string `yaml:"description,omitempty"`
Tags []string `yaml:"tags,omitempty"`
OperationID string `yaml:"operationId,omitempty"`
Parameters []Parameter `yaml:"parameters,omitempty"`
RequestBody RequestBody `yaml:"requestBody,omitempty"`
Responses []Response `yaml:"responses,omitempty"`
Callbacks []Callback `yaml:"callbacks,omitempty"`
}
type EnumOptionX ¶
type EnumX ¶
type EnumX struct {
Options []EnumOptionX
}
type RequestBody ¶
type RequestBody struct {
Required bool `yaml:"required,omitempty"`
Description string `yaml:"description,omitempty"`
ContentTypes ContentTypes `yaml:"content,omitempty"`
Example string `yaml:"example,omitempty"`
}
type Response ¶
type Response struct {
Ref string `yaml:"$ref,omitempty"`
Status string `yaml:"status,omitempty"`
Description string `yaml:"description,omitempty"`
ContentTypes ContentTypes `yaml:"content,omitempty"`
}
type Schema ¶
type Schema struct {
// Key is dependent on where the schema was found. It may represent the name
// of the Schema if it's the root spec components map, but it's
// the key of the property is it was found as a nested schema.
Key string `yaml:"key,omitempty"`
// Name is the name of the schema if it's present in the
// components schemas section
Name string `yaml:"name,omitempty"`
Ref string `yaml:"$ref,omitempty"`
Type string `yaml:"type,omitempty"`
Description string `yaml:"description,omitempty"`
Title string `yaml:"title,omitempty"`
Required []string `yaml:"required,omitempty"`
Nullable bool `yaml:"Nullable,omitempty"`
Format string `yaml:"format,omitempty"`
Pattern string `yaml:"pattern,omitempty"`
ReadOnly bool `yaml:"readOnly,omitempty"`
WriteOnly bool `yaml:"writeOnly,omitempty"`
Minimum float64 `yaml:"minimum,omitempty"`
Maximum float64 `yaml:"maximum,omitempty"`
ExclusiveMinimum float64 `yaml:"exclusiveMinimum,omitempty"`
ExclusiveMaximum float64 `yaml:"exclusiveMaximum,omitempty"`
MinItems int `yaml:"minItems,omitempty"`
MaxItems int `yaml:"maxItems,omitempty"`
UniqueItems bool `yaml:"uniqueItems,omitempty"`
MinLength int `yaml:"minLength,omitempty"`
MaxLength int `yaml:"maxLength,omitempty"`
MinProperties int `yaml:"minProperties,omitempty"`
MaxProperties int `yaml:"maxProperties,omitempty"`
Enum []string `yaml:"enum,omitempty"`
EnumX EnumX `yaml:"x-enum,omitempty"`
Example string `yaml:"example,omitempty"`
Default string `yaml:"default,omitempty"`
Properties []Schema `yaml:"properties,omitempty"`
Items *Schema `yaml:"items,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.